@@ -17,6 +17,9 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 账户余额不足。
+FAILEDOPERATION_ACCOUNTINSUFFICIENT = 'FailedOperation.AccountInsufficient'
+
 # API网关触发器创建失败。
 FAILEDOPERATION_APIGATEWAY = 'FailedOperation.ApiGateway'
 
@@ -41,6 +44,9 @@ FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
 # CLS服务未注册。
 FAILEDOPERATION_CLSSERVICEUNREGISTERED = 'FailedOperation.ClsServiceUnregistered'
 
+# 函数集群不存在。
+FAILEDOPERATION_CLUSTERNOTFOUND = 'FailedOperation.ClusterNotFound'
+
 # CopyAsyncRun 传参异常。
 FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
 
@@ -107,6 +113,9 @@ FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
 # 当前账号或命名空间处于欠费状态，请在可用时重试。
 FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 
+# 本地域资源售罄。
+FAILEDOPERATION_INSUFFICIENTRESOURCES = 'FailedOperation.InsufficientResources'
+
 # 调用函数失败。
 FAILEDOPERATION_INVOKEFUNCTION = 'FailedOperation.InvokeFunction'
 
@@ -143,6 +152,9 @@ FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 # 角色不存在。
 FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
 
+# 查询失败。
+FAILEDOPERATION_QUERYERROR = 'FailedOperation.QueryError'
+
 # ReservedExceedTotal 总保留超限。
 FAILEDOPERATION_RESERVEDEXCEEDTOTAL = 'FailedOperation.ReservedExceedTotal'
 
@@ -173,6 +185,9 @@ FAILEDOPERATION_UPDATEFUNCTIONCONFIGURATION = 'FailedOperation.UpdateFunctionCon
 # 更新状态操作失败。
 FAILEDOPERATION_UPDATESTATUS = 'FailedOperation.UpdateStatus'
 
+# 更新触发器出错。
+FAILEDOPERATION_UPDATETRIGGER = 'FailedOperation.UpdateTrigger'
+
 # 与原状态一致，无需更改。
 FAILEDOPERATION_UPDATETRIGGERSTATUS = 'FailedOperation.UpdateTriggerStatus'
 
@@ -257,6 +272,9 @@ INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
 # Args 参数值有误。
 INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
 
+# 容器启动参数取值与规范不符。
+INVALIDPARAMETERVALUE_ARGSLIST = 'InvalidParameterValue.ArgsList'
+
 # AsyncRunEnable 取值不正确。
 INVALIDPARAMETERVALUE_ASYNCRUNENABLE = 'InvalidParameterValue.AsyncRunEnable'
 
@@ -302,6 +320,9 @@ INVALIDPARAMETERVALUE_CODESOURCE = 'InvalidParameterValue.CodeSource'
 # Command[Entrypoint] 参数值有误。
 INVALIDPARAMETERVALUE_COMMAND = 'InvalidParameterValue.Command'
 
+# 容器启动命令参数值与规范不符。
+INVALIDPARAMETERVALUE_COMMANDLIST = 'InvalidParameterValue.CommandList'
+
 # CompatibleRuntimes参数传入错误。
 INVALIDPARAMETERVALUE_COMPATIBLERUNTIMES = 'InvalidParameterValue.CompatibleRuntimes'
 
@@ -344,6 +365,9 @@ INVALIDPARAMETERVALUE_DEMOID = 'InvalidParameterValue.DemoId'
 # Description传入错误。
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
+# DiskSize 参数取值不规范。
+INVALIDPARAMETERVALUE_DISKSIZE = 'InvalidParameterValue.DiskSize'
+
 # 环境变量DNS[OS_NAMESERVER]配置有误。
 INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
 
@@ -440,6 +464,9 @@ INVALIDPARAMETERVALUE_LIMIT = 'InvalidParameterValue.Limit'
 # 参数超出长度限制。
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
+# 日志格式不正确。
+INVALIDPARAMETERVALUE_LOGFORMAT = 'InvalidParameterValue.LogFormat'
+
 # MaxConcurrency 参数传入错误。
 INVALIDPARAMETERVALUE_MAXCONCURRENCY = 'InvalidParameterValue.MaxConcurrency'
 
@@ -566,6 +593,9 @@ INVALIDPARAMETERVALUE_TRIGGERPROVISIONEDCONCURRENCYNUM = 'InvalidParameterValue.
 # Type传入错误。
 INVALIDPARAMETERVALUE_TYPE = 'InvalidParameterValue.Type'
 
+# VPC不正确。
+INVALIDPARAMETERVALUE_VPC = 'InvalidParameterValue.Vpc'
+
 # 开启cfs配置的同时必须开启vpc。
 INVALIDPARAMETERVALUE_VPCNOTSETWHENOPENCFS = 'InvalidParameterValue.VpcNotSetWhenOpenCfs'
 
@@ -638,6 +668,9 @@ LIMITEXCEEDED_NAMESPACE = 'LimitExceeded.Namespace'
 # Offset超出限制。
 LIMITEXCEEDED_OFFSET = 'LimitExceeded.Offset'
 
+# 特权容器属性开启失败
+LIMITEXCEEDED_PRIVILEGECONTAINER = 'LimitExceeded.PrivilegeContainer'
+
 # 定时预置数量超过最大限制。
 LIMITEXCEEDED_PROVISIONTRIGGERACTION = 'LimitExceeded.ProvisionTriggerAction'
 
@@ -674,6 +707,9 @@ MISSINGPARAMETER_RUNTIME = 'MissingParameter.Runtime'
 # 账号已被隔离。
 OPERATIONDENIED_ACCOUNTISOLATE = 'OperationDenied.AccountIsolate'
 
+# 账号不存在。
+OPERATIONDENIED_ACCOUNTNOTEXISTS = 'OperationDenied.AccountNotExists'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -806,6 +842,9 @@ RESOURCEUNAVAILABLE_INSUFFICIENTBALANCE = 'ResourceUnavailable.InsufficientBalan
 # Namespace不可用。
 RESOURCEUNAVAILABLE_NAMESPACE = 'ResourceUnavailable.Namespace'
 
+# 服务已冻结。
+RESOURCEUNAVAILABLE_SERVICESUSPENDED = 'ResourceUnavailable.ServiceSuspended'
+
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
@@ -854,21 +893,33 @@ UNSUPPORTEDOPERATION_ASYNCRUNENABLE = 'UnsupportedOperation.AsyncRunEnable'
 # Cdn不支持。
 UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 
+# 该函数无法复制。
+UNSUPPORTEDOPERATION_COPYFUNCTION = 'UnsupportedOperation.CopyFunction'
+
 # Cos操作不支持。
 UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 
+# DiskSize 配置内测中，需要申请开启。如需使用可联系我们。
+UNSUPPORTEDOPERATION_DISKSIZE = 'UnsupportedOperation.DiskSize'
+
 # 指定的配置EipFixed暂不支持。
 UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
 
 # 不支持的地域。
 UNSUPPORTEDOPERATION_NOTSUPPORTREGION = 'UnsupportedOperation.NotSupportRegion'
 
+# 当前状态无法发布版本。
+UNSUPPORTEDOPERATION_PUBLISHVERSION = 'UnsupportedOperation.PublishVersion'
+
 # 不支持此地域。
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
 # Trigger操作不支持。
 UNSUPPORTEDOPERATION_TRIGGER = 'UnsupportedOperation.Trigger'
 
+# 更新函数代码失败。
+UNSUPPORTEDOPERATION_UPDATEFUNCTIONCODE = 'UnsupportedOperation.UpdateFunctionCode'
+
 # 指定的配置暂不支持，请修正后再试。
 UNSUPPORTEDOPERATION_UPDATEFUNCTIONEVENTINVOKECONFIG = 'UnsupportedOperation.UpdateFunctionEventInvokeConfig'
 
